@@ -414,25 +414,63 @@ bc.plot <- function(x, a=1, b=2, p=0.9, ...) {
 }
 
 # make data.frame of lambdas vector from Maxent model object
-lambdasDF <- function(mx) {
-  lambdas <- mx@lambdas[1:(length(mx@lambdas)-4)]
-  data.frame(var=sapply(lambdas, FUN=function(x) strsplit(x, ',')[[1]][1]),
-             coef=sapply(lambdas, FUN=function(x) as.numeric(strsplit(x, ',')[[1]][2])),
-             min=sapply(lambdas, FUN=function(x) as.numeric(strsplit(x, ',')[[1]][3])),
-             max=sapply(lambdas, FUN=function(x) as.numeric(strsplit(x, ',')[[1]][4])),
-             row.names=1:length(lambdas))
+lambdasDF <- function(m, maxentVersion) {
+  if(maxentVersion == "maxent.jar") {
+    lambdas <- m@lambdas[1:(length(m@lambdas)-4)]
+    data.frame(var=sapply(lambdas, FUN=function(x) strsplit(x, ',')[[1]][1]),
+               coef=sapply(lambdas, FUN=function(x) as.numeric(strsplit(x, ',')[[1]][2])),
+               min=sapply(lambdas, FUN=function(x) as.numeric(strsplit(x, ',')[[1]][3])),
+               max=sapply(lambdas, FUN=function(x) as.numeric(strsplit(x, ',')[[1]][4])),
+               row.names=1:length(lambdas))  
+  } else if(maxentVersion == "maxnet") {
+    lambdas <- m$betas
+    if(sum(grepl("hinge", names(lambdas))) > 0) {
+      hinges <- which(grepl("hinge", names(lambdas)))
+      hinges.ranges <- gsub("[a-z]|\\s*\\([^\\)]+\\):", "", names(lambdas)[hinges])
+      hinges.fmins <- as.numeric(sapply(hinges.ranges, function(x) strsplit(x, split = ":")[[1]][1]))
+      hinges.fmaxs <- as.numeric(sapply(hinges.ranges, function(x) strsplit(x, split = ":")[[1]][2]))
+      nonhinges <- which(!grepl("hinge", names(lambdas)))
+      nonhinges.fmins <- as.numeric(m$featuremins[nonhinges])
+      nonhinges.fmaxs <- as.numeric(m$featuremaxs[nonhinges])
+      fmins <- c(nonhinges.fmins, hinges.fmins)
+      fmaxs <- c(nonhinges.fmaxs, hinges.fmaxs)
+    } else {
+      fmins <- as.numeric(m$featuremins)
+      fmaxs <- as.numeric(m$featuremaxs)
+    }
+    # if variables that are not in lambdas are included in mins/maxs, remove them
+    fmins <- fmins[names(m$featuremins) %in% names(lambdas)]
+    fmaxs <- fmaxs[names(m$featuremaxs) %in% names(lambdas)]
+    data.frame(var=gsub("(:[^:]+):.*", "", names(lambdas)),
+               coef=as.numeric(lambdas),
+               min=fmins,
+               max=fmaxs,
+               row.names=1:length(lambdas))
+  }
+  
 }
 ## pulls out all non-zero, non-redundant (removes hinge/product/threshold) predictor names
-mxNonzeroCoefs <- function(mx) {
-  x <- lambdasDF(mx)
-  #remove any rows that have a zero lambdas value (Second column)
-  x <- x[(x[,2] != 0),]
-  #remove any rows that have duplicate "var"s (hinges, quadratics)
-  x <- unique(sub("\\^\\S*", "", x[,1]))
-  x <- unique(sub("\\`", "", x))
-  x <- unique(sub("\\'", "", x))
-  x <- unique(sub("\\=\\S*", "", x))
-  x <- unique(sub("\\(", "", x))
+mxNonzeroCoefs <- function(mx, maxentVersion = "maxnet") {
+  if(maxentVersion == "maxnet") {
+    x <- lambdasDF(mx, maxentVersion = "maxnet")
+    #remove any rows that have a zero lambdas value (Second column)
+    x <- x[(x[,2] != 0),]
+    #remove any rows that have duplicate "var"s (hinges, quadratics)
+    x <- unique(sub("\\^\\S*", "", x[,1]))
+    x <- unique(sub("[I]\\(", "", x))
+    x <- unique(sub("hinge\\(", "", x))
+    x <- unique(sub("\\)", "", x))
+  } else if(maxentVersion == "maxent.jar") {
+    x <- lambdasDF(mx, maxentVersion = "maxent.jar")
+    #remove any rows that have a zero lambdas value (Second column)
+    x <- x[(x[,2] != 0),]
+    #remove any rows that have duplicate "var"s (hinges, quadratics)
+    x <- unique(sub("\\^\\S*", "", x[,1]))
+    x <- unique(sub("\\`", "", x))
+    x <- unique(sub("\\'", "", x))
+    x <- unique(sub("\\=\\S*", "", x))
+    x <- unique(sub("\\(", "", x))
+  }
 }
 
 respCurv <- function(mod, i) {  # copied mostly from dismo
@@ -506,7 +544,7 @@ comp8_map <- function(map, ras, polyXY, bgShpXY, rasVals, rasCols,
     clearMarkers() %>% 
     clearShapes() %>%
     removeImage(clearID) %>%
-    addRasterImage(ras, colors = rasPal, opacity = 0.7, 
+    addRasterImage(ras, colors = rasPal, opacity = 0.9, 
                    group = 'c7', layerId = addID) %>%
     addPolygons(lng=polyXY[,1], lat=polyXY[,2], layerId="projExt", fill = FALSE,
                 weight=4, color="green", group='c8')
@@ -547,3 +585,21 @@ printVecAsis <- function(x) {
     }
   }
 }
+
+#####################
+# Download utlities #
+#####################
+
+convert_list_cols <- function(x) {
+  dplyr::mutate_if(.tbl = x,
+                   .predicate = function(col) inherits(col, "list"),
+                   .funs = function(col) {
+                     vapply(col,
+                            jsonlite::toJSON,
+                            character(1L))
+                   })
+}
+
+write_csv_robust <- function(x, ...) {
+  write.csv(convert_list_cols(x), ...)
+}
