@@ -25,13 +25,15 @@ bgMskAndSamplePts_MOD <- function(input, output, session, rvs) {
     rvs %>% writeLog('Environmental data masked.')
     # sample random background points
     withProgress(message = "Generating background points...", {
-      rvals <- raster::getValues(bgMask)
-      num.vals <- sum(!is.na(rvals))
-      pct <- round((input$bgPtsNum / num.vals) * 100, digits = 2)
       bgXY <- dismo::randomPoints(bgMask, input$bgPtsNum)
     })
-    rvs %>% writeLog('Random background points sampled (n =', input$bgPtsNum, 
-                      ':', pct, '% of cells with values).')
+    bg.prop <- round(nrow(bgXY)/input$bgPtsNum, digits = 2)
+    if(bg.prop == 1) {
+      rvs %>% writeLog("Random background points sampled (n =", input$bgPtsNum, ").")
+    } else {
+      rvs %>% writeLog("Random background points requested (n =", input$bgPtsNum, 
+                       "), but only ", 100*bg.prop, "% of points (n = ", nrow(bgXY), ") were able to be sampled.")
+    }
     shinyjs::enable("downloadMskPreds")
     return(list(msk = bgMask, pts = bgXY))
   })
